NAME

Bored - news!

VERSION

Version 0.04

SYNOPSIS

use Bored qw/bored_one/;

bored_one;

my $you = Bored->new();
$you->pointless();
$you->waiting();
$you->tortured();
...

AUTHOR

LNATION <email@lnation.org>

BUGS

Please report any bugs or feature requests to bug-bored at rt.cpan.org, or through the web interface at https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Bored. I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc Bored

You can also look for information at:

ACKNOWLEDGEMENTS

LICENSE AND COPYRIGHT

This software is Copyright (c) 2026 by LNATION <email@lnation.org>.

This is free software, licensed under:

The Artistic License 2.0 (GPL Compatible)